@@ -1,35 +1,45 @@
 #' @title Classification Learner for Debugging
 #'
+#' @usage NULL
 #' @aliases mlr_learners_classif.debug
 #' @format [R6::R6Class] inheriting from [LearnerClassif].
 #' @include LearnerClassif.R
 #'
+#' @section Construction:
+#' ```
+#' LearnerClassifDebug$new()
+#' mlr_learners$get("classif.debug")
+#' lrn("classif.debug")
+#' ```
+#'
 #' @description
 #' A simple [LearnerClassif] used primarily in the unit tests and for debugging purposes.
 #' If no hyperparameter is set, it simply constantly predicts a randomly selected label.
 #' The following hyperparameters trigger the following actions:
 #' \describe{
-#'    \item{message_train:}{Outputs a message during train if `runif(1)` exceeds its value.}
-#'    \item{message_predict:}{Outputs a message during predict if `runif(1)` exceeds its value.}
-#'    \item{warning_train:}{Signals a warning during train if `runif(1)` exceeds its value.}
-#'    \item{warning_predict:}{Signals a warning during predict if `runif(1)` exceeds its value.}
-#'    \item{error_train:}{Raises an exception during train if `runif(1)` exceeds its value.}
-#'    \item{error_predict:}{Raises an exception during predict if `runif(1)` exceeds its value.}
-#'    \item{segfault_train:}{Provokes a segfault during train if `runif(1)` exceeds its value.}
-#'    \item{segfault_predict:}{Provokes a segfault during predict if `runif(1)` exceeds its value.}
+#'    \item{message_train:}{Outputs a message during train if the parameter value exceeds `runif(1)`.}
+#'    \item{message_predict:}{Outputs a message during predict if the parameter value exceeds `runif(1)`.}
+#'    \item{warning_train:}{Signals a warning during train if the parameter value exceeds `runif(1)`.}
+#'    \item{warning_predict:}{Signals a warning during predict if the parameter value exceeds `runif(1)`.}
+#'    \item{error_train:}{Raises an exception during train if the parameter value exceeds `runif(1)`.}
+#'    \item{error_predict:}{Raises an exception during predict if the parameter value exceeds `runif(1)`.}
+#'    \item{segfault_train:}{Provokes a segfault during train if the parameter value exceeds `runif(1)`.}
+#'    \item{segfault_predict:}{Provokes a segfault during predict if the parameter value exceeds `runif(1)`.}
 #'    \item{predict_missing}{Ratio of predictions which will be NA.}
 #'    \item{save_tasks:}{Saves input task in `model` slot during training and prediction.}
-#'    \item{x:}{Numeric parameter. Ignored.}
+#'    \item{x:}{Numeric parameter. Has no effect.}
 #' }
 #' Note that segfaults may not work on your operating system.
 #' Also note that if they work, they will tear down your R session immediately!
+#'
+#' @template seealso_learner
 #' @export
 #' @examples
-#' learner = LearnerClassifDebug$new()
+#' learner = lrn("classif.debug")
 #' learner$param_set$values = list(message_train = 1, save_tasks = TRUE)
 #'
 #' # this should signal a message
-#' task = mlr_tasks$get("iris")
+#' task = tsk("iris")
 #' learner$train(task)
 #' learner$predict(task)
 #'
@@ -37,9 +47,9 @@
 #' names(learner$model)
 LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
   public = list(
-    initialize = function(id = "classif.debug") {
+    initialize = function() {
       super$initialize(
-        id = id,
+        id = "classif.debug",
         feature_types = c("logical", "integer", "numeric", "character", "factor", "ordered"),
         predict_types = c("response", "prob"),
         param_set = ParamSet$new(
@@ -62,8 +72,11 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
     },
 
     train_internal = function(task) {
+
       pv = self$param_set$get_values(tags = "train")
-      lookup = function(name) { name %in% names(pv) && pv[[name]] > runif(1L) }
+      lookup = function(name) {
+        name %in% names(pv) && pv[[name]] > runif(1L)
+      }
 
       if (lookup("message_train")) {
         message("Message from classif.debug->train()")
@@ -86,9 +99,12 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
     },
 
     predict_internal = function(task) {
+
       n = task$nrow
       pv = self$param_set$get_values(tags = "predict")
-      lookup = function(name) { name %in% names(pv) && pv[[name]] > runif(1L) }
+      lookup = function(name) {
+        name %in% names(pv) && pv[[name]] > runif(1L)
+      }
 
       if (lookup("message_predict")) {
         message("Message from classif.debug->predict()")
@@ -104,7 +120,7 @@ LearnerClassifDebug = R6Class("LearnerClassifDebug", inherit = LearnerClassif,
       }
 
       if (isTRUE(pv$save_tasks)) {
-        self$data$model$task_predict = task$clone(deep = TRUE)
+        self$state$model$task_predict = task$clone(deep = TRUE)
       }
 
       response = prob = NULL
