@@ -58,32 +58,30 @@
 ResamplingRepeatedCV = R6Class("ResamplingRepeatedCV", inherit = Resampling,
   public = list(
     initialize = function() {
-      super$initialize(
-        id = "repeated_cv",
-        param_set = ParamSet$new(params = list(
-          ParamUty$new("stratify", default = NULL),
-          ParamInt$new("repeats", lower = 1),
-          ParamInt$new("folds", lower = 1L, tags = "required")
-        )),
-        param_vals = list(repeats = 10L, folds = 10L)
-      )
+      ps = ParamSet$new(list(
+        ParamUty$new("stratify", default = NULL),
+        ParamInt$new("repeats", lower = 1),
+        ParamInt$new("folds", lower = 1L, tags = "required")
+      ))
+      ps$values = list(repeats = 10L, folds = 10L)
+      super$initialize(id = "repeated_cv", param_set = ps)
     },
 
     folds = function(iters) {
       iters = assert_integerish(iters, any.missing = FALSE, coerce = TRUE)
-      ((iters - 1L) %% self$param_set$values$repeats) + 1L
+      ((iters - 1L) %% as.integer(self$param_set$values$repeats)) + 1L
     },
 
     repeats = function(iters) {
       iters = assert_integerish(iters, any.missing = FALSE, coerce = TRUE)
-      ((iters - 1L) %/% self$param_set$values$folds) + 1L
+      ((iters - 1L) %/% as.integer(self$param_set$values$folds)) + 1L
     }
   ),
 
   active = list(
     iters = function() {
       pv = self$param_set$values
-      pv$repeats * pv$folds
+      as.integer(pv$repeats) * as.integer(pv$folds)
     }
   ),
 
@@ -91,26 +89,26 @@ ResamplingRepeatedCV = R6Class("ResamplingRepeatedCV", inherit = Resampling,
     .sample = function(ids) {
       pv = self$param_set$values
       n = length(ids)
-      folds = pv$folds
+      folds = as.integer(pv$folds)
       map_dtr(seq_len(pv$repeats), function(i) {
         data.table(row_id = ids, rep = i, fold = shuffle(seq_len0(n) %% folds + 1L))
       })
     },
 
     .get_train = function(i) {
-      i = i - 1L
+      i = as.integer(i) - 1L
       folds = as.integer(self$param_set$values$folds)
-      rep = as.integer(i %/% folds) + 1L
-      fold = as.integer(i %% folds) + 1L
+      rep = i %/% folds + 1L
+      fold = i %% folds + 1L
       ii = data.table(rep = rep, fold = seq_len(folds)[-fold])
       self$instance[ii, "row_id", on = names(ii), nomatch = 0L][[1L]]
     },
 
     .get_test = function(i) {
-      i = i - 1L
+      i = as.integer(i) - 1L
       folds = as.integer(self$param_set$values$folds)
-      rep = as.integer(i %/% folds) + 1L
-      fold = as.integer(i %% folds) + 1L
+      rep = i %/% folds + 1L
+      fold = i %% folds + 1L
       ii = data.table(rep = rep, fold = fold)
       self$instance[ii, "row_id", on = names(ii), nomatch = 0L][[1L]]
     },
