@@ -33,3 +33,17 @@ allow_partial_matching = list(
   warnPartialMatchAttr = FALSE,
   warnPartialMatchDollar = FALSE
 )
+
+# determines if execution via future will be running locally or remotely
+use_future = function() {
+  if (!isNamespaceLoaded("future") || inherits(future::plan(), "uniprocess")) {
+    return(FALSE)
+  }
+
+  if (!requireNamespace("future.apply", quietly = TRUE)) {
+    lg$warn("Package 'future.apply' could not be loaded. Parallelization disabled.")
+    return(FALSE)
+  }
+
+  return(TRUE)
+}
