@@ -16,7 +16,7 @@ test_that("Classification measures", {
         m$costs = costs
       }
       perf = m$score(prediction = p, task = task, learner = learner)
-      expect_number(perf, na.ok = m$na_score, lower = m$range[1], upper = m$range[2])
+      expect_number(perf, na.ok = "na_score" %in% m$properties, lower = m$range[1], upper = m$range[2])
     }
   }
 })
